==> qbs-src-1.11.0.zip: qbs-src-1.11.0/src/lib/corelib/tools/executablefinder.h <==
/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qbs.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 3 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL3 included in the
** packaging of this file. Please review the following information to
** ensure the GNU Lesser General Public License version 3 requirements
** will be met: https://www.gnu.org/licenses/lgpl-3.0.html.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 2.0 or (at your option) the GNU General
** Public license version 3 or any later version approved by the KDE Free
** Qt Foundation. The licenses are as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL2 and LICENSE.GPL3
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-2.0.html and
** https://www.gnu.org/licenses/gpl-3.0.html.
**
** $QT_END_LICENSE$
**
****************************************************************************/

#ifndef QBS_EXECUTABLEFINDER_H
#define QBS_EXECUTABLEFINDER_H

#include <language/language.h>

#include <QtCore/qprocess.h>

namespace qbs {
namespace Internal {

/*!
 * \brief Helper class for finding an executable in the PATH of the build environment.
 */
class ExecutableFinder
{
public:
    ExecutableFinder(const ResolvedProductPtr &product, const QProcessEnvironment &env);

    QString findExecutable(const QString &path, const QString &workingDirPath);

private:
    static QStringList m_executableSuffixes;
    QString findBySuffix(const QString &filePath) const;
    bool candidateCheck(const QString &directory, const QString &program,
            QString &fullProgramPath) const;
    QString findInPath(const QString &filePath, const QString &workingDirPath) const;

    QString cachedFilePath(const QString &filePath) const;
    void cacheFilePath(const QString &filePaht, const QString &filePath) const;

    ResolvedProductPtr m_product;
    const QProcessEnvironment &m_environment;
};

} // namespace Internal
} // namespace qbs

#endif // QBS_EXECUTABLEFINDER_H

==> qbs-src-2.6.0.zip: qbs-src-2.6.0/src/lib/corelib/tools/executablefinder.h <==
/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qbs.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 3 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL3 included in the
** packaging of this file. Please review the following information to
** ensure the GNU Lesser General Public License version 3 requirements
** will be met: https://www.gnu.org/licenses/lgpl-3.0.html.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 2.0 or (at your option) the GNU General
** Public license version 3 or any later version approved by the KDE Free
** Qt Foundation. The licenses are as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL2 and LICENSE.GPL3
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-2.0.html and
** https://www.gnu.org/licenses/gpl-3.0.html.
**
** $QT_END_LICENSE$
**
****************************************************************************/

#ifndef QBS_EXECUTABLEFINDER_H
#define QBS_EXECUTABLEFINDER_H

#include <language/language.h>

#include <QtCore/qprocess.h>

namespace qbs {
namespace Internal {

/*!
 * \brief Helper class for finding an executable in the PATH of the build environment.
 */
class ExecutableFinder
{
public:
    ExecutableFinder(ResolvedProductPtr product, const QProcessEnvironment &env);

    QString findExecutable(const QString &path, const QString &workingDirPath);

private:
    static QStringList m_executableSuffixes;
    QString findBySuffix(const QString &filePath) const;
    bool candidateCheck(const QString &directory, const QString &program,
            QString &fullProgramPath) const;
    QString findInPath(const QString &filePath, const QString &workingDirPath) const;

    QString cachedFilePath(const QString &filePath) const;
    void cacheFilePath(const QString &filePaht, const QString &filePath) const;

    ResolvedProductPtr m_product;
    const QProcessEnvironment m_environment;
};

} // namespace Internal
} // namespace qbs

#endif // QBS_EXECUTABLEFINDER_H
